import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ExtensionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html#config Extension#config}.
     *
     * @stability stable
     */
    readonly config?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html#endpoint_url Extension#endpoint_url}.
     *
     * @stability stable
     */
    readonly endpointUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html#extension_objects Extension#extension_objects}.
     *
     * @stability stable
     */
    readonly extensionObjects: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html#extension_schema Extension#extension_schema}.
     *
     * @stability stable
     */
    readonly extensionSchema: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html#name Extension#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html#type Extension#type}.
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html pagerduty_extension}.
 *
 * @stability stable
 */
export declare class Extension extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/pagerduty/r/extension.html pagerduty_extension} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ExtensionConfig);
    private _config?;
    /**
     * @stability stable
     */
    get config(): string | undefined;
    /**
     * @stability stable
     */
    set config(value: string | undefined);
    /**
     * @stability stable
     */
    resetConfig(): void;
    /**
     * @stability stable
     */
    get configInput(): string | undefined;
    private _endpointUrl?;
    /**
     * @stability stable
     */
    get endpointUrl(): string | undefined;
    /**
     * @stability stable
     */
    set endpointUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetEndpointUrl(): void;
    /**
     * @stability stable
     */
    get endpointUrlInput(): string | undefined;
    private _extensionObjects?;
    /**
     * @stability stable
     */
    get extensionObjects(): string[];
    /**
     * @stability stable
     */
    set extensionObjects(value: string[]);
    /**
     * @stability stable
     */
    get extensionObjectsInput(): string[] | undefined;
    private _extensionSchema?;
    /**
     * @stability stable
     */
    get extensionSchema(): string;
    /**
     * @stability stable
     */
    set extensionSchema(value: string);
    /**
     * @stability stable
     */
    get extensionSchemaInput(): string | undefined;
    /**
     * @stability stable
     */
    get htmlUrl(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string | undefined;
    /**
     * @stability stable
     */
    set name(value: string | undefined);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string | undefined;
    /**
     * @stability stable
     */
    set type(value: string | undefined);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
