import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ScheduleConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#description Schedule#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#name Schedule#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#overflow Schedule#overflow}.
     *
     * @stability stable
     */
    readonly overflow?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#teams Schedule#teams}.
     *
     * @stability stable
     */
    readonly teams?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#time_zone Schedule#time_zone}.
     *
     * @stability stable
     */
    readonly timeZone: string;
    /**
     * layer block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#layer Schedule#layer}
     *
     * @stability stable
     */
    readonly layer: ScheduleLayer[];
}
/**
 * @stability stable
 */
export interface ScheduleLayerRestriction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#duration_seconds Schedule#duration_seconds}.
     *
     * @stability stable
     */
    readonly durationSeconds: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#start_day_of_week Schedule#start_day_of_week}.
     *
     * @stability stable
     */
    readonly startDayOfWeek?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#start_time_of_day Schedule#start_time_of_day}.
     *
     * @stability stable
     */
    readonly startTimeOfDay: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#type Schedule#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface ScheduleLayer {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#end Schedule#end}.
     *
     * @stability stable
     */
    readonly end?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#name Schedule#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#rotation_turn_length_seconds Schedule#rotation_turn_length_seconds}.
     *
     * @stability stable
     */
    readonly rotationTurnLengthSeconds: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#rotation_virtual_start Schedule#rotation_virtual_start}.
     *
     * @stability stable
     */
    readonly rotationVirtualStart: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#start Schedule#start}.
     *
     * @stability stable
     */
    readonly start: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#users Schedule#users}.
     *
     * @stability stable
     */
    readonly users: string[];
    /**
     * restriction block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html#restriction Schedule#restriction}
     *
     * @stability stable
     */
    readonly restriction?: ScheduleLayerRestriction[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html pagerduty_schedule}.
 *
 * @stability stable
 */
export declare class Schedule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/pagerduty/r/schedule.html pagerduty_schedule} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ScheduleConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string | undefined;
    /**
     * @stability stable
     */
    set description(value: string | undefined);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string | undefined;
    /**
     * @stability stable
     */
    set name(value: string | undefined);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _overflow?;
    /**
     * @stability stable
     */
    get overflow(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set overflow(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetOverflow(): void;
    /**
     * @stability stable
     */
    get overflowInput(): boolean | cdktf.IResolvable | undefined;
    private _teams?;
    /**
     * @stability stable
     */
    get teams(): string[] | undefined;
    /**
     * @stability stable
     */
    set teams(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetTeams(): void;
    /**
     * @stability stable
     */
    get teamsInput(): string[] | undefined;
    private _timeZone?;
    /**
     * @stability stable
     */
    get timeZone(): string;
    /**
     * @stability stable
     */
    set timeZone(value: string);
    /**
     * @stability stable
     */
    get timeZoneInput(): string | undefined;
    private _layer?;
    /**
     * @stability stable
     */
    get layer(): ScheduleLayer[];
    /**
     * @stability stable
     */
    set layer(value: ScheduleLayer[]);
    /**
     * @stability stable
     */
    get layerInput(): ScheduleLayer[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
